.. _bigfeta-schema-label:

BigFeta schema
================

.. automodule:: bigfeta.schemas
    :members: BigFetaSchema, input_stack, output_stack, pointmatch, hdf5_options, matrix_assembly, regularization, BigFetaPlotSchema
    :undoc-members:
    :show-inheritance:
